/*

*/
import java.awt.Color;

public class StandardCube
{
   public static void main(String[] args)
   {
      // Here are the vertices of the standard cube.
      Vertex[] v = { new Vertex(0, 0, 0), // count from 0 to to 7 in binary
                     new Vertex(0, 0, 1),
                     new Vertex(0, 1, 0),
                     new Vertex(0, 1, 1),
                     new Vertex(1, 0, 0),
                     new Vertex(1, 0, 1),
                     new Vertex(1, 1, 0),
                     new Vertex(1, 1, 1) };

      // Now make the 12 triangles.
      Triangle[] t = { new Triangle(v[0], v[1], v[3]),  // 0 1 2 3
                       new Triangle(v[3], v[2], v[0]),

                       new Triangle(v[0], v[1], v[5]),  // 0 1 4 5
                       new Triangle(v[5], v[4], v[0]),

                       new Triangle(v[0], v[2], v[6]),  // 0 2 4 6
                       new Triangle(v[6], v[4], v[0]),

                       new Triangle(v[1], v[3], v[7]),  // 1 3 5 7
                       new Triangle(v[7], v[5], v[1]),

                       new Triangle(v[2], v[3], v[7]),  // 2 3 6 7
                       new Triangle(v[7], v[6], v[2]),

                       new Triangle(v[4], v[5], v[7]),  // 4 5 6 7
                       new Triangle(v[7], v[6], v[4])};

      // Create an empty Model object.
      Model m1 = new Model();

      // Put the triangles in the Model
      // (and give each triangle a random color).
      for (int i = 0; i < t.length; i++)
      {
         t[i].v[0].setColorRandom();
         t[i].setColor( t[i].v[0].getColor() );
         m1.triangleList.add( t[i] );
      }

      // Create the Scene object that we shall render
      Scene scene = new Scene();

      // Add the model to the Scene.
      scene.modelList.add( m1 );

      // Give the Scene a view matrix.
      scene.view2Identity();

      // Give the scene a projection matrix.
      scene.proj2Identity();

      // Set up the scene's view frustum.
      double fov    = 60.0;
      double aspect = 1.0;
      double near   = 1.0;
      double far    = 20.0;
      scene.projPerspective(fov, aspect, near, far);

      // Set up the scene's "camera".
      double eyex=0,    eyey=0,    eyez=10;
      double centerx=0, centery=0, centerz=0;
      double upx=0,     upy=1,     upz=0;
      scene.viewLookAt(eyex,    eyey,    eyez,
                       centerx, centery, centerz,
                       upx,     upy,     upz);

      System.err.println( scene.toString() );
      System.err.println( m1.toString(1) );

      // Create a framebuffer to render our scene into.
      int vp_width  = 512;
      int vp_height = 512;
      FrameBuffer fb = new FrameBuffer(vp_width, vp_height);
      // Give the framebuffer a nice background color.
      fb.clearFB(java.awt.Color.darkGray);
      // Render our scene into the frame buffer.
      SceneRender.renderScene(scene, fb);
      // Save the resulting image in a file.
      fb.dumpFB2File( String.format("StandardCube_Frame%03d.ppm", 0) );

      // Move the model to the right.
      for (int i = 1; i <= 10; i++)
      {
         // Move the model to the right.
         m1.modelTranslate( 0.1, 0, 0);

         // And raise the model.
         m1.modelTranslate(0, 0.1, 0);

         // Render again.
         fb.clearFB(java.awt.Color.darkGray);
         SceneRender.renderScene(scene, fb);
         fb.dumpFB2File(String.format("StandardCube_Frame%03d.ppm", i));
      }
   }
}